@@ -1,6 +1,7 @@
 
 #include "kstringhandlertest.h"
 
+#include <QRegularExpression>
 #include <QTest>
 
 QTEST_MAIN(KStringHandlerTest)
@@ -57,6 +58,8 @@ void KStringHandlerTest::perlSplit()
     expected << QStringLiteral("Split") << QStringLiteral("me") << QStringLiteral("up ! I'm bored ! OK ?");
     QCOMPARE(KStringHandler::perlSplit(QRegExp(QStringLiteral("[! ]")),
                                        QStringLiteral("Split me up ! I'm bored ! OK ?"), 3), expected);
+    QCOMPARE(KStringHandler::perlSplit(QRegularExpression(QStringLiteral("[! ]")),
+                                       QStringLiteral("Split me up ! I'm bored ! OK ?"), 3), expected);
 }
 
 void KStringHandlerTest::obscure()
