@@ -1,22 +1,10 @@
-/*  This file is part of the KDE project
-    Copyright (C) 2007 Matthias Kretz <kretz@kde.org>
-    Copyright (C) 2007 Bernhard Loos <nhuh.put@web.de>
+/*
+    This file is part of the KDE project
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-FileCopyrightText: 2007 Matthias Kretz <kretz@kde.org>
+    SPDX-FileCopyrightText: 2007 Bernhard Loos <nhuh.put@web.de>
 
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KPLUGINFACTORY_H
@@ -24,9 +12,9 @@
 
 #include "kcoreaddons_export.h"
 
-#include <QtCore/QObject>
-#include <QtCore/QVariant>
-#include <QtCore/QStringList>
+#include <QObject>
+#include <QVariant>
+#include <QStringList>
 #include <kexportplugin.h> // for source compat
 
 class QWidget;
@@ -344,14 +332,14 @@ public:
 
     /**
      * Use this method to create an object. It will try to create an object which inherits
-     * \p T. If it has multiple choices, you will get a fatal error (kFatal()), so be careful
+     * \p T. If it has multiple choices it's not defined which object will be returned, so be careful
      * to request a unique interface or use keywords.
      *
      * \tparam T The interface for which an object should be created. The object will inherit \p T.
      * \param parent The parent of the object. If \p parent is a widget type, it will also passed
      *               to the parentWidget argument of the CreateInstanceFunction for the object.
      * \param args Additional arguments which will be passed to the object.
-     * \returns A pointer to the created object is returned, or 0 if an error occurred.
+     * \returns A pointer to the created object is returned, or @c nullptr if an error occurred.
      */
     template<typename T>
     T *create(QObject *parent = nullptr, const QVariantList &args = QVariantList());
@@ -365,7 +353,7 @@ public:
      * \param parent The parent of the object. If \p parent is a widget type, it will also passed
      *               to the parentWidget argument of the CreateInstanceFunction for the object.
      * \param args Additional arguments which will be passed to the object.
-     * \returns A pointer to the created object is returned, or 0 if an error occurred.
+     * \returns A pointer to the created object is returned, or @c nullptr if an error occurred.
      */
     template<typename T>
     T *create(const QString &keyword, QObject *parent = nullptr, const QVariantList &args = QVariantList());
@@ -381,28 +369,27 @@ public:
      *               to the parentWidget argument of the CreateInstanceFunction for the object.
      * \param keyword The keyword of the object.
      * \param args Additional arguments which will be passed to the object.
-     * \returns A pointer to the created object is returned, or 0 if an error occurred.
+     * \returns A pointer to the created object is returned, or @c nullptr if an error occurred.
      */
     template<typename T>
     T *create(QWidget *parentWidget, QObject *parent, const QString &keyword = QString(), const QVariantList &args = QVariantList());
 
+#if KCOREADDONS_ENABLE_DEPRECATED_SINCE(4, 0)
     /**
      * @deprecated since 4.0 use create<T>(QObject *parent, const QVariantList &args)
      */
-#ifndef KCOREADDONS_NO_DEPRECATED
     template<typename T>
-    KCOREADDONS_DEPRECATED
+    KCOREADDONS_DEPRECATED_VERSION(4, 0, "Use KPluginFactory::create<T>(QObject *parent, const QVariantList &args)")
     T *create(QObject *parent, const QStringList &args)
     {
         return create<T>(parent, stringListToVariantList(args));
     }
-#endif
 
     /**
      * @deprecated since 4.0 use create<T>(QObject *parent, const QVariantList &args)
      */
-#ifndef KCOREADDONS_NO_DEPRECATED
-    KCOREADDONS_DEPRECATED QObject *create(QObject *parent = nullptr, const char *classname = "QObject", const QStringList &args = QStringList())
+    KCOREADDONS_DEPRECATED_VERSION(4, 0, "Use KPluginFactory::create<T>(QObject *parent, const QVariantList &args)")
+    QObject *create(QObject *parent = nullptr, const char *classname = "QObject", const QStringList &args = QStringList())
     {
         return create(classname, nullptr, parent, stringListToVariantList(args), QString());
     }
@@ -484,32 +471,32 @@ protected:
      */
     template<class T>
     void registerPlugin(const QString &keyword = QString(), CreateInstanceFunction instanceFunction
-                        = InheritanceChecker<T>().createInstanceFunction(reinterpret_cast<T *>(0)))
+                        = InheritanceChecker<T>().createInstanceFunction(static_cast<T *>(nullptr)))
     {
         registerPlugin(keyword, &T::staticMetaObject, instanceFunction);
     }
 
     KPluginFactoryPrivate *const d_ptr;
 
+#if KCOREADDONS_BUILD_DEPRECATED_SINCE(4, 0)
     /**
      * @deprecated since 4.0 use create<T>(QObject *parent, const QVariantList &args)
      */
-#ifndef KCOREADDONS_NO_DEPRECATED
-    virtual KCOREADDONS_DEPRECATED QObject *createObject(QObject *parent, const char *className, const QStringList &args);
-#endif
+    KCOREADDONS_DEPRECATED_VERSION(4, 0, "Use KPluginFactory::create<T>(QObject *parent, const QVariantList &args)")
+    virtual QObject *createObject(QObject *parent, const char *className, const QStringList &args);
 
     /**
      * @deprecated since 4.0 use create<T>(QWidget *parentWidget, QObject *parent, const QString &keyword, const QVariantList &args)
      */
-#ifndef KCOREADDONS_NO_DEPRECATED
-    virtual KCOREADDONS_DEPRECATED KParts::Part *createPartObject(QWidget *parentWidget, QObject *parent, const char *classname, const QStringList &args);
+    KCOREADDONS_DEPRECATED_VERSION(4, 0, "Use KPluginFactory::create<T>(QWidget *parentWidget, QObject *parent, const QString &keyword, const QVariantList &args)")
+    virtual KParts::Part *createPartObject(QWidget *parentWidget, QObject *parent, const char *classname, const QStringList &args);
 #endif
 
     /**
      * This function is called when the factory asked to create an Object.
      *
      * You may reimplement it to provide a very flexible factory. This is especially useful to
-     * provide generic factories for plugins implemeted using a scripting language.
+     * provide generic factories for plugins implemented using a scripting language.
      *
      * \param iface The staticMetaObject::className() string identifying the plugin interface that
      * was requested. E.g. for KCModule plugins this string will be "KCModule".
@@ -524,7 +511,7 @@ protected:
     template<class impl, class ParentType>
     static QObject *createInstance(QWidget *parentWidget, QObject *parent, const QVariantList &args)
     {
-        Q_UNUSED(parentWidget);
+        Q_UNUSED(parentWidget)
         ParentType *p = nullptr;
         if (parent) {
             p = qobject_cast<ParentType *>(parent);
