@@ -1,19 +1,9 @@
-/*  This file is part of the KDE project
-    Copyright (C) 2007 Bernhard Loos <nhuh.put@web.de>
+/*
+    This file is part of the KDE project
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License version 2 as published by the Free Software Foundation.
+    SPDX-FileCopyrightText: 2007 Bernhard Loos <nhuh.put@web.de>
 
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 #ifndef KPLUGINLOADER_H
 #define KPLUGINLOADER_H
@@ -21,7 +11,6 @@
 #include <kexportplugin.h>
 
 #include <QPluginLoader>
-#include <QtPlugin>
 
 #include <functional>
 
