@@ -1,19 +1,9 @@
-/*  This file is part of the KDE project
-    Copyright (C) 2014 Alex Richardson <arichardson.kde@gmail.com>
+/*
+    This file is part of the KDE project
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License version 2 as published by the Free Software Foundation.
+    SPDX-FileCopyrightText: 2014 Alex Richardson <arichardson.kde@gmail.com>
 
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #include "kpluginmetadata.h"
@@ -23,6 +13,7 @@
 #include <QJsonArray>
 #include <QJsonDocument>
 #include <QLocale>
+#include <QMimeDatabase>
 #include <QPluginLoader>
 #include <QStringList>
 #include "kcoreaddons_debug.h"
@@ -59,9 +50,9 @@ KPluginMetaData::~KPluginMetaData()
 
 KPluginMetaData::KPluginMetaData(const QString &file)
 {
-    if (file.endsWith(QStringLiteral(".desktop"))) {
+    if (file.endsWith(QLatin1String(".desktop"))) {
         loadFromDesktopFile(file, QStringList());
-    } else if (file.endsWith(QStringLiteral(".json"))) {
+    } else if (file.endsWith(QLatin1String(".json"))) {
         d = new KPluginMetaDataPrivate;
         QFile f(file);
         bool b = f.open(QIODevice::ReadOnly);
@@ -331,6 +322,21 @@ QStringList KPluginMetaData::mimeTypes() const
     return readStringList(rootObject(), QStringLiteral("MimeTypes"));
 }
 
+bool KPluginMetaData::supportsMimeType(const QString &mimeType) const
+{
+    QMimeDatabase db;
+    const QMimeType mime = db.mimeTypeForName(mimeType);
+    if (!mime.isValid()) {
+        return false;
+    }
+
+    const QStringList mimes = mimeTypes();
+    auto inherits = [&](const QString &supportedMimeName) {
+        return mime.inherits(supportedMimeName);
+    };
+    return std::find_if(mimes.begin(), mimes.end(), inherits) != mimes.end();
+}
+
 QStringList KPluginMetaData::formFactors() const
 {
     return readStringList(rootObject(), QStringLiteral("FormFactors"));
@@ -347,6 +353,11 @@ bool KPluginMetaData::isEnabledByDefault() const
     return false;
 }
 
+int KPluginMetaData::initialPreference() const
+{
+    return rootObject()[QStringLiteral("InitialPreference")].toInt();
+}
+
 QString KPluginMetaData::value(const QString &key, const QString &defaultValue) const
 {
     const QJsonValue value = m_metaData.value(key);
